# OnDemandQueueEntry


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**complete** | **bool** |  | [optional] 
**completion_time** | **int** |  | [optional] 
**creation_time** | **int** |  | [optional] 
**data_type** | **str** |  | [optional] 
**device_id** | **str** |  | [optional] 
**end_time** | **int** |  | [optional] 
**id** | **str** |  | [optional] 
**start_processing_time** | **int** |  | [optional] 
**start_time** | **int** |  | [optional] 
**status** | **str** |  | [optional] 
**tenant_id** | **str** |  | [optional] 
**time_period** | **str** |  | [optional] 
**value** | **int** |  | [optional] 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


